@@ -13,9 +13,10 @@ from edupage_api.people import EduAccount
 
 
 # data.dbi.event_types
-class EventType(Enum):
+class EventType(str, Enum):
     # Messages
     MESSAGE = "sprava"
+    POLL = "anketa"
     NEWS = "news"
 
     # ****************************************
@@ -109,6 +110,7 @@ class EventType(Enum):
     ALBUM = "album"
 
     # Other
+    BEE = "vcelicka"
     OTHER = "other"
 
     # Helper
@@ -129,6 +131,7 @@ class EventType(Enum):
     H_SETTINGS = "h_settings"
     H_SUBSTITUTION = "h_substitution"
     H_TIMETABLE = "h_timetable"
+    H_USERPHOTO = "h_userphoto"
 
     @staticmethod
     def parse(event_type_str: str) -> Optional[EventType]:
